#include <SoftwareSerial.h>


#define LED_PIN 13                // Change this to the pin where you have connected the LED
SoftwareSerial BTSerial(10, 11);  // RX, TX pins for JDY-23 Bluetooth module
const int STATE_PIN = 7;          // The pin connected to the STATE pin of the HC-05 module.

bool isLedOn = false;                          // Track the state of the LED
unsigned long lastDataTime = 0;                // Store the last time data was received from Bluetooth
const unsigned long connectionTimeout = 5000;  // Set the timeout duration in milliseconds (5 seconds)

unsigned long lastCommandTime = 0;
const unsigned long commandInterval = 100;  // Set your desired interval here, e.g., 100 ms


void setup() {

  pinMode(LED_PIN, OUTPUT);
  digitalWrite(LED_PIN, LOW);

  Serial.begin(9600);         // Serial communication for debugging
  BTSerial.begin(9600);       // Bluetooth module baud rate
  pinMode(STATE_PIN, INPUT);  // Set the STATE_PIN as an input.
}

void loop() {

  bool isConnected = digitalRead(STATE_PIN);

  // Check for incoming data from the phone
  if (BTSerial.available()) {
    char command = BTSerial.read();
    // Process the received command
    switch (command) {
      case '0':
        digitalWrite(LED_PIN, LOW);  // Turn OFF the LED
        isLedOn = false;             // Update the LED state variable
        break;
      case '1':
        digitalWrite(LED_PIN, HIGH);  // Turn ON the LED
        isLedOn = true;               // Update the LED state variable
        break;
      default:
        // Invalid command received
        break;
    }

    // Record the time when data was last received
    lastDataTime = millis();
  }

  // Check if the Bluetooth connection is still active

  unsigned long currentTime = millis();

  // Send the command at the specified interval
  if (currentTime - lastCommandTime >= commandInterval) {
    lastCommandTime = currentTime;
    //BTSerial.println("Busy"); // Send AT command to check the Bluetooth connection status.
  }

  // Check for response if available
  while (BTSerial.available()) {
    char response = BTSerial.read();
    if (response == '01') {
      // Bluetooth connection is still active
    } else if (response == '00') {
      // Bluetooth connection is lost, turn off the LED
      digitalWrite(LED_PIN, LOW);
      isLedOn = false;  // Update the LED state variable
    }
  }

  // Check if the Bluetooth module is connected by reading the STATE_PIN. between App and Car
  if (isConnected) {
    //Serial.println("Bluetooth device is connected.");
    Serial.println(digitalRead(STATE_PIN));
    BTSerial.println("test");
  } else {
    Serial.println(digitalRead(STATE_PIN));
  }
}